/*
 * Copyright 2017, GeoSolutions Sas.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree.
 */

import React from 'react';
import ReactDOM from 'react-dom';
import ReactTestUtils from 'react-dom/test-utils';
import expect from 'expect';
import {compose, defaultProps} from 'recompose';
import chartWidget from '../../enhancers/chartWidget';
import BaseChartWidget from '../ChartWidget';
const ChartWidget = compose(defaultProps({
    canEdit: true
}), chartWidget)(BaseChartWidget);

describe('ChartWidget component', () => {
    beforeEach((done) => {
        document.body.innerHTML = '<div id="container"></div>';
        setTimeout(done);
    });
    afterEach((done) => {
        ReactDOM.unmountComponentAtNode(document.getElementById("container"));
        document.body.innerHTML = '';
        setTimeout(done);
    });
    it('ChartWidget rendering with defaults', () => {
        ReactDOM.render(<ChartWidget />, document.getElementById("container"));
        const container = document.getElementById('container');
        const el = container.querySelector('.mapstore-widget-card');
        expect(container.querySelector('.glyphicon-pencil')).toExist();
        expect(container.querySelector('.glyphicon-trash')).toExist();
        expect(el).toExist();
    });
    it('view only mode', () => {
        ReactDOM.render(<ChartWidget canEdit={false} />, document.getElementById("container"));
        const container = document.getElementById('container');
        expect(container.querySelector('.glyphicon-pencil')).toNotExist();
        expect(container.querySelector('.glyphicon-trash')).toNotExist();
    });
    it('Test ChartWidget onEdit callback', () => {
        const actions = {
            onEdit: () => {}
        };
        const spyonEdit = expect.spyOn(actions, 'onEdit');
        ReactDOM.render(<ChartWidget onEdit={actions.onEdit} />, document.getElementById("container"));
        const container = document.getElementById('container');
        const el = container.querySelector('.glyphicon-pencil');
        ReactTestUtils.Simulate.click(el); // <-- trigger event callback
        expect(spyonEdit).toHaveBeenCalled();
    });
    it('Test ChartWidget with chartSwitcher', () => {
        const charts = [{chartId: 1, layer: {title: "test1"}}, {chartId: 2, layer: {title: "test2"}}];
        ReactDOM.render(<ChartWidget topRightItems={[]} charts={charts} />, document.getElementById("container"));
        const container = document.getElementById('container');
        const el = container.querySelector('.chart-switcher');
        expect(el).toBeTruthy();
    });
    it('Test ChartWidget render chartSwitcher on table view', () => {
        const charts = [{chartId: 1, layer: {title: "test1"}}, {chartId: 2, layer: {title: "test2"}}];
        ReactDOM.render(<ChartWidget showTable charts={charts} />, document.getElementById("container"));
        const container = document.getElementById('container');
        const el = container.querySelector('.chart-switcher');
        expect(el).toBeTruthy();
    });
});
